library(frbs)
library(batch)
library(RSNNS)
seed <- 101
set.seed(seed)

## Start input data
load("iris.5f.RData")

tra.iris.1 <- data.frame(iris.5.1.tra)
tra.iris.2 <- data.frame(iris.5.2.tra)
tra.iris.3 <- data.frame(iris.5.3.tra)
tra.iris.4 <- data.frame(iris.5.4.tra)
tra.iris.5 <- data.frame(iris.5.5.tra)
names.attrs <- c("Sepal.Length", "Sepal.Width", "Petal.Length",
                            "Petal.Width", "Species")
colnames(tra.iris.1) <- names.attrs
colnames(tra.iris.2) <- names.attrs
colnames(tra.iris.3) <- names.attrs
colnames(tra.iris.4) <- names.attrs
colnames(tra.iris.5) <- names.attrs
							

tst.iris.1 <- data.frame(iris.5.1.tst[, 1 : 4])
tst.iris.2 <- data.frame(iris.5.2.tst[, 1 : 4])
tst.iris.3 <- data.frame(iris.5.3.tst[, 1 : 4])
tst.iris.4 <- data.frame(iris.5.4.tst[, 1 : 4])
tst.iris.5 <- data.frame(iris.5.5.tst[, 1 : 4])
names.out.attr <- c("Sepal.Length", "Sepal.Width", "Petal.Length",
                            "Petal.Width")
colnames(tst.iris.1) <- names.out.attr
colnames(tst.iris.2) <- names.out.attr
colnames(tst.iris.3) <- names.out.attr
colnames(tst.iris.4) <- names.out.attr
colnames(tst.iris.5) <- names.out.attr

real.iris.1 <- data.frame(matrix(iris.5.1.tst[, 5], ncol = 1))
real.iris.2 <- data.frame(matrix(iris.5.2.tst[, 5], ncol = 1))
real.iris.3 <- data.frame(matrix(iris.5.3.tst[, 5], ncol = 1))
real.iris.4 <- data.frame(matrix(iris.5.4.tst[, 5], ncol = 1))
real.iris.5 <- data.frame(matrix(iris.5.5.tst[, 5], ncol = 1))

## generate model using classification tree with default parameters (for simplicity).
iris.1 <- normTrainingAndTestSet(list(inputsTrain = tra.iris.1[, -ncol(tra.iris.1), drop = FALSE], 
                          targetsTrain = tra.iris.1[, ncol(tra.iris.1), drop = FALSE], 
                          inputsTest = tst.iris.1, targetsTest = real.iris.1))
iris.2 <- normTrainingAndTestSet(list(inputsTrain = tra.iris.2[, -ncol(tra.iris.1), drop = FALSE], 
                          targetsTrain = tra.iris.2[, ncol(tra.iris.2), drop = FALSE], 
                          inputsTest = tst.iris.2, targetsTest = real.iris.2))
iris.3 <- normTrainingAndTestSet(list(inputsTrain = tra.iris.3[, -ncol(tra.iris.3), drop = FALSE], 
                          targetsTrain = tra.iris.3[, ncol(tra.iris.3), drop = FALSE], 
                          inputsTest = tst.iris.3, targetsTest = real.iris.3))
iris.4 <- normTrainingAndTestSet(list(inputsTrain = tra.iris.4[, -ncol(tra.iris.4), drop = FALSE], 
                          targetsTrain = tra.iris.4[, ncol(tra.iris.4), drop = FALSE], 
                          inputsTest = tst.iris.4, targetsTest = real.iris.4))
iris.5 <- normTrainingAndTestSet(list(inputsTrain = tra.iris.5[, -ncol(tra.iris.5), drop = FALSE], 
                          targetsTrain = tra.iris.5[, ncol(tra.iris.5), drop = FALSE], 
                          inputsTest = tst.iris.5, targetsTest = real.iris.5))						  

object.mlp.1 <- mlp(iris.1$inputsTrain, iris.1$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=iris.1$inputsTest, targetsTest=iris.1$targetsTest, linOut=TRUE)
object.mlp.2 <- mlp(iris.2$inputsTrain, iris.2$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=iris.2$inputsTest, targetsTest=iris.2$targetsTest, linOut=TRUE)
object.mlp.3 <- mlp(iris.3$inputsTrain, iris.3$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=iris.3$inputsTest, targetsTest=iris.3$targetsTest, linOut=TRUE)
object.mlp.4 <- mlp(iris.4$inputsTrain, iris.4$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=iris.4$inputsTest, targetsTest=iris.4$targetsTest, linOut=TRUE)
object.mlp.5 <- mlp(iris.5$inputsTrain, iris.5$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=iris.5$inputsTest, targetsTest=iris.5$targetsTest, linOut=TRUE)

pred.1 <- predict(object.mlp.1, iris.1$inputsTest)
pred.2 <- predict(object.mlp.2, iris.2$inputsTest)
pred.3 <- predict(object.mlp.3, iris.3$inputsTest)
pred.4 <- predict(object.mlp.4, iris.4$inputsTest)
pred.5 <- predict(object.mlp.5, iris.5$inputsTest)

err.1 = 100*sum(real.iris.1!=round(pred.1))/nrow(pred.1)
err.2 = 100*sum(real.iris.2!=round(pred.2))/nrow(pred.2)
err.3 = 100*sum(real.iris.3!=round(pred.3))/nrow(pred.3)
err.4 = 100*sum(real.iris.4!=round(pred.4))/nrow(pred.4)
err.5 = 100*sum(real.iris.5!=round(pred.5))/nrow(pred.5)

err.aver <- (err.1 + err.2 + err.3 + err.4 + err.5)/5
print("average error")
print(err.aver)