library(RSNNS)
library(frbs)
library(batch)
seed <- 101
set.seed(seed)
## Start input data
load("pima.5f.RData")
tra.pima.1 <- data.frame(pima.5.1.tra)
tra.pima.2 <- data.frame(pima.5.2.tra)
tra.pima.3 <- data.frame(pima.5.3.tra)
tra.pima.4 <- data.frame(pima.5.4.tra)
tra.pima.5 <- data.frame(pima.5.5.tra)							

tst.pima.1 <- data.frame(pima.5.1.tst[, -ncol(pima.5.1.tst)])
tst.pima.2 <- data.frame(pima.5.2.tst[, -ncol(pima.5.2.tst)])
tst.pima.3 <- data.frame(pima.5.3.tst[, -ncol(pima.5.3.tst)])
tst.pima.4 <- data.frame(pima.5.4.tst[, -ncol(pima.5.4.tst)])
tst.pima.5 <- data.frame(pima.5.5.tst[, -ncol(pima.5.5.tst)])

real.pima.1 <- data.frame(matrix(pima.5.1.tst[, ncol(pima.5.1.tst)], ncol = 1))
real.pima.2 <- data.frame(matrix(pima.5.2.tst[, ncol(pima.5.2.tst)], ncol = 1))
real.pima.3 <- data.frame(matrix(pima.5.3.tst[, ncol(pima.5.3.tst)], ncol = 1))
real.pima.4 <- data.frame(matrix(pima.5.4.tst[, ncol(pima.5.4.tst)], ncol = 1))
real.pima.5 <- data.frame(matrix(pima.5.5.tst[, ncol(pima.5.5.tst)], ncol = 1))

## generate model using classification tree with default parameters (for simplicity).
pima.1 <- normTrainingAndTestSet(list(inputsTrain = tra.pima.1[, -ncol(tra.pima.1), drop = FALSE], 
                          targetsTrain = tra.pima.1[, ncol(tra.pima.1), drop = FALSE], 
                          inputsTest = tst.pima.1, targetsTest = real.pima.1))
pima.2 <- normTrainingAndTestSet(list(inputsTrain = tra.pima.2[, -ncol(tra.pima.1), drop = FALSE], 
                          targetsTrain = tra.pima.2[, ncol(tra.pima.2), drop = FALSE], 
                          inputsTest = tst.pima.2, targetsTest = real.pima.2))
pima.3 <- normTrainingAndTestSet(list(inputsTrain = tra.pima.3[, -ncol(tra.pima.3), drop = FALSE], 
                          targetsTrain = tra.pima.3[, ncol(tra.pima.3), drop = FALSE], 
                          inputsTest = tst.pima.3, targetsTest = real.pima.3))
pima.4 <- normTrainingAndTestSet(list(inputsTrain = tra.pima.4[, -ncol(tra.pima.4), drop = FALSE], 
                          targetsTrain = tra.pima.4[, ncol(tra.pima.4), drop = FALSE], 
                          inputsTest = tst.pima.4, targetsTest = real.pima.4))
pima.5 <- normTrainingAndTestSet(list(inputsTrain = tra.pima.5[, -ncol(tra.pima.5), drop = FALSE], 
                          targetsTrain = tra.pima.5[, ncol(tra.pima.5), drop = FALSE], 
                          inputsTest = tst.pima.5, targetsTest = real.pima.5))						  

object.mlp.1 <- mlp(pima.1$inputsTrain, pima.1$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=pima.1$inputsTest, targetsTest=pima.1$targetsTest, linOut=TRUE)
object.mlp.2 <- mlp(pima.2$inputsTrain, pima.2$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=pima.2$inputsTest, targetsTest=pima.2$targetsTest, linOut=TRUE)
object.mlp.3 <- mlp(pima.3$inputsTrain, pima.3$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=pima.3$inputsTest, targetsTest=pima.3$targetsTest, linOut=TRUE)
object.mlp.4 <- mlp(pima.4$inputsTrain, pima.4$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=pima.4$inputsTest, targetsTest=pima.4$targetsTest, linOut=TRUE)
object.mlp.5 <- mlp(pima.5$inputsTrain, pima.5$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=pima.5$inputsTest, targetsTest=pima.5$targetsTest, linOut=TRUE)

pred.1 <- predict(object.mlp.1, pima.1$inputsTest)
pred.2 <- predict(object.mlp.2, pima.2$inputsTest)
pred.3 <- predict(object.mlp.3, pima.3$inputsTest)
pred.4 <- predict(object.mlp.4, pima.4$inputsTest)
pred.5 <- predict(object.mlp.5, pima.5$inputsTest)

err.1 = 100*sum(real.pima.1!=round(pred.1))/nrow(real.pima.1)
err.2 = 100*sum(real.pima.2!=round(pred.2))/nrow(real.pima.2)
err.3 = 100*sum(real.pima.3!=round(pred.3))/nrow(real.pima.3)
err.4 = 100*sum(real.pima.4!=round(pred.4))/nrow(real.pima.4)
err.5 = 100*sum(real.pima.5!=round(pred.5))/nrow(real.pima.5)

err.aver <- (err.1 + err.2 + err.3 + err.4 + err.5)/5
print("average error")
print(err.aver)