library(RSNNS)
library(batch)
seed <- 101
set.seed(seed)
library(frbs)

## Start input data
load("wine.5f.RData")
tra.wine.1 <- data.frame(wine.5.1.tra)
tra.wine.2 <- data.frame(wine.5.2.tra)
tra.wine.3 <- data.frame(wine.5.3.tra)
tra.wine.4 <- data.frame(wine.5.4.tra)
tra.wine.5 <- data.frame(wine.5.5.tra)
							
tst.wine.1 <- data.frame(wine.5.1.tst[, -ncol(wine.5.1.tst)])
tst.wine.2 <- data.frame(wine.5.2.tst[, -ncol(wine.5.2.tst)])
tst.wine.3 <- data.frame(wine.5.3.tst[, -ncol(wine.5.3.tst)])
tst.wine.4 <- data.frame(wine.5.4.tst[, -ncol(wine.5.4.tst)])
tst.wine.5 <- data.frame(wine.5.5.tst[, -ncol(wine.5.5.tst)])

real.wine.1 <- data.frame(matrix(wine.5.1.tst[, ncol(wine.5.1.tst)], ncol = 1))
real.wine.2 <- data.frame(matrix(wine.5.2.tst[, ncol(wine.5.2.tst)], ncol = 1))
real.wine.3 <- data.frame(matrix(wine.5.3.tst[, ncol(wine.5.3.tst)], ncol = 1))
real.wine.4 <- data.frame(matrix(wine.5.4.tst[, ncol(wine.5.4.tst)], ncol = 1))
real.wine.5 <- data.frame(matrix(wine.5.5.tst[, ncol(wine.5.5.tst)], ncol = 1))

## generate model using classification tree with default parameters (for simplicity).
wine.1 <- normTrainingAndTestSet(list(inputsTrain = tra.wine.1[, -ncol(tra.wine.1), drop = FALSE], 
                          targetsTrain = tra.wine.1[, ncol(tra.wine.1), drop = FALSE], 
                          inputsTest = tst.wine.1, targetsTest = real.wine.1))
wine.2 <- normTrainingAndTestSet(list(inputsTrain = tra.wine.2[, -ncol(tra.wine.1), drop = FALSE], 
                          targetsTrain = tra.wine.2[, ncol(tra.wine.2), drop = FALSE], 
                          inputsTest = tst.wine.2, targetsTest = real.wine.2))
wine.3 <- normTrainingAndTestSet(list(inputsTrain = tra.wine.3[, -ncol(tra.wine.3), drop = FALSE], 
                          targetsTrain = tra.wine.3[, ncol(tra.wine.3), drop = FALSE], 
                          inputsTest = tst.wine.3, targetsTest = real.wine.3))
wine.4 <- normTrainingAndTestSet(list(inputsTrain = tra.wine.4[, -ncol(tra.wine.4), drop = FALSE], 
                          targetsTrain = tra.wine.4[, ncol(tra.wine.4), drop = FALSE], 
                          inputsTest = tst.wine.4, targetsTest = real.wine.4))
wine.5 <- normTrainingAndTestSet(list(inputsTrain = tra.wine.5[, -ncol(tra.wine.5), drop = FALSE], 
                          targetsTrain = tra.wine.5[, ncol(tra.wine.5), drop = FALSE], 
                          inputsTest = tst.wine.5, targetsTest = real.wine.5))						  

object.mlp.1 <- mlp(wine.1$inputsTrain, wine.1$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=wine.1$inputsTest, targetsTest=wine.1$targetsTest, linOut=TRUE)
object.mlp.2 <- mlp(wine.2$inputsTrain, wine.2$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=wine.2$inputsTest, targetsTest=wine.2$targetsTest, linOut=TRUE)
object.mlp.3 <- mlp(wine.3$inputsTrain, wine.3$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=wine.3$inputsTest, targetsTest=wine.3$targetsTest, linOut=TRUE)
object.mlp.4 <- mlp(wine.4$inputsTrain, wine.4$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=wine.4$inputsTest, targetsTest=wine.4$targetsTest, linOut=TRUE)
object.mlp.5 <- mlp(wine.5$inputsTrain, wine.5$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=wine.5$inputsTest, targetsTest=wine.5$targetsTest, linOut=TRUE)

pred.1 <- predict(object.mlp.1, wine.1$inputsTest)
pred.2 <- predict(object.mlp.2, wine.2$inputsTest)
pred.3 <- predict(object.mlp.3, wine.3$inputsTest)
pred.4 <- predict(object.mlp.4, wine.4$inputsTest)
pred.5 <- predict(object.mlp.5, wine.5$inputsTest)

err.1 = 100*sum(real.wine.1!=round(pred.1))/nrow(pred.1)
err.2 = 100*sum(real.wine.2!=round(pred.2))/nrow(pred.2)
err.3 = 100*sum(real.wine.3!=round(pred.3))/nrow(pred.3)
err.4 = 100*sum(real.wine.4!=round(pred.4))/nrow(pred.4)
err.5 = 100*sum(real.wine.5!=round(pred.5))/nrow(pred.5)

err.aver <- (err.1 + err.2 + err.3 + err.4 + err.5)/5
print("average error")
print(err.aver)