library(kernlab)
library(batch)
seed <- 101
set.seed(seed)
library(frbs)

## Start input data
load("wine.5f.RData")
tra.wine.1 <- data.frame(wine.5.1.tra)
tra.wine.2 <- data.frame(wine.5.2.tra)
tra.wine.3 <- data.frame(wine.5.3.tra)
tra.wine.4 <- data.frame(wine.5.4.tra)
tra.wine.5 <- data.frame(wine.5.5.tra)
names.attrs <- c("c1", "c2", "c3", "c4", "c5", "c6", "c7", "c8", "c9", 
						"c10", "c11", "c12", "c13", "c14")
colnames(tra.wine.1) <- names.attrs
colnames(tra.wine.2) <- names.attrs
colnames(tra.wine.3) <- names.attrs
colnames(tra.wine.4) <- names.attrs
colnames(tra.wine.5) <- names.attrs
							

tst.wine.1 <- data.frame(wine.5.1.tst[, 1 : 13])
tst.wine.2 <- data.frame(wine.5.2.tst[, 1 : 13])
tst.wine.3 <- data.frame(wine.5.3.tst[, 1 : 13])
tst.wine.4 <- data.frame(wine.5.4.tst[, 1 : 13])
tst.wine.5 <- data.frame(wine.5.5.tst[, 1 : 13])
names.outatt <- c("c1", "c2", "c3", "c4", "c5", "c6", "c7", "c8", 
                        "c9", "c10", "c11", "c12", "c13")
colnames(tst.wine.1) <- names.outatt
colnames(tst.wine.2) <- names.outatt
colnames(tst.wine.3) <- names.outatt
colnames(tst.wine.4) <- names.outatt
colnames(tst.wine.5) <- names.outatt


real.wine.1 <- data.frame(matrix(wine.5.1.tst[, 14], ncol = 1))
real.wine.2 <- data.frame(matrix(wine.5.2.tst[, 14], ncol = 1))
real.wine.3 <- data.frame(matrix(wine.5.3.tst[, 14], ncol = 1))
real.wine.4 <- data.frame(matrix(wine.5.4.tst[, 14], ncol = 1))
real.wine.5 <- data.frame(matrix(wine.5.5.tst[, 14], ncol = 1))

## generate model using classification SVM with default parameters (for simplicity).
object.SVM.1 <- ksvm(c14 ~., data = tra.wine.1, type = "C-bsvc", kernel = "rbfdot", kpar = list(sigma = 0.1), C= 10, prob.model = TRUE)
object.SVM.2 <- ksvm(c14 ~., data = tra.wine.2, type = "C-bsvc", kernel = "rbfdot", kpar = list(sigma = 0.1), C= 10, prob.model = TRUE)
object.SVM.3 <- ksvm(c14 ~., data = tra.wine.3, type = "C-bsvc", kernel = "rbfdot", kpar = list(sigma = 0.1), C= 10, prob.model = TRUE)
object.SVM.4 <- ksvm(c14 ~., data = tra.wine.4, type = "C-bsvc", kernel = "rbfdot", kpar = list(sigma = 0.1), C= 10, prob.model = TRUE)
object.SVM.5 <- ksvm(c14 ~., data = tra.wine.5, type = "C-bsvc", kernel = "rbfdot", kpar = list(sigma = 0.1), C= 10, prob.model = TRUE)

pred.1 <- as.matrix(predict(object.SVM.1, tst.wine.1))
pred.2 <- as.matrix(predict(object.SVM.2, tst.wine.2))
pred.3 <- as.matrix(predict(object.SVM.3, tst.wine.3))
pred.4 <- as.matrix(predict(object.SVM.4, tst.wine.4))
pred.5 <- as.matrix(predict(object.SVM.5, tst.wine.5))

err.1 = 100*sum(real.wine.1!=pred.1)/nrow(real.wine.1)
err.2 = 100*sum(real.wine.2!=pred.2)/nrow(real.wine.2)
err.3 = 100*sum(real.wine.3!=pred.3)/nrow(real.wine.3)
err.4 = 100*sum(real.wine.4!=pred.4)/nrow(real.wine.4)
err.5 = 100*sum(real.wine.5!=pred.5)/nrow(real.wine.5)

err.aver <- (err.1 + err.2 + err.3 + err.4 +err.5)/5
print(err.aver)