library(batch)
seed <- 101
parseCommandArgs()
set.seed(seed)
library(frbs)
library(e1071)

## input data
data(frbsData)
frbsData$GasFurnance <- frbsData$GasFurnance[sample(nrow(frbsData$GasFurnance)), ]
data.train <- frbsData$GasFurnance.dt[1 : 204, ]
data.fit <- data.train[, 1 : 2]
data.tst <- frbsData$GasFurnance.dt[205 : 292, 1 : 2]
real.val <- matrix(frbsData$GasFurnance.dt[205 : 292, 3], ncol = 1)
range.data<-matrix(c(-2.716, 2.834, 45.6, 60.5, 45.6, 60.5), nrow=2)


svm.GF <- svm(x = data.train[, -ncol(data.train)], y = data.train[, ncol(data.train)], 
                    cost = 10, gamma = 0.01)
				
pred <- predict(svm.GF, data.tst)


benchmark <- cbind(real.val, pred)

colnames(benchmark) <- c("real", "tree")
print(benchmark)
residuals <- (real.val - pred)
MSE <- mean(residuals^2)
RMSE <- sqrt(mean(residuals^2))
SMAPE <- mean(abs(residuals)/(abs(real.val) + abs(pred))/2)*100
err <- c(MSE, RMSE, SMAPE)
names(err) <- c("MSE", "RMSE", "SMAPE")
print("Error Measurement: ")
print(err) 
