library(frbs)
library(batch)
library(RSNNS)
seed <- 101
parseCommandArgs()
set.seed(seed)

## Input data
data(frbsData)
frbsData$MackeyGlass1000.dt <- frbsData$MackeyGlass1000.dt[sample(nrow(frbsData$MackeyGlass1000.dt)), ]
data.train <- frbsData$MackeyGlass1000.dt[1: 500, ]
data.fit <- data.train[, 1 : 4]
data.tst <- frbsData$MackeyGlass1000.dt[501 : 1000, 1 : 4]
real.val <- matrix(frbsData$MackeyGlass1000.dt[501 : 1000, 5], ncol = 1)
range.data<-matrix(c(0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105), nrow=2)

colnames(data.train) <- c("d1", "d2", "d3", "d4", "d5")
colnames(data.fit) <- c("d1", "d2", "d3", "d4")
colnames(data.tst) <- c("d1", "d2", "d3", "d4")
							

## generate model using classification tree with default parameters (for simplicity).
MG <- normTrainingAndTestSet(list(inputsTrain = data.train[, -ncol(data.train), drop = FALSE], 
                          targetsTrain = data.train[, ncol(data.train), drop = FALSE], 
                          inputsTest = data.tst, targetsTest = real.val))
					  

object.mlp <- mlp(MG$inputsTrain, MG$targetsTrain, size=5, learnFuncParams=c(0.1),
            maxit=350, inputsTest=MG$inputsTest, targetsTest=MG$targetsTest, linOut=TRUE)

pred <- predict(object.mlp, MG$inputsTest)

benchmark <- cbind(real.val, pred)

colnames(benchmark) <- c("real", "tree")
print(benchmark)
residuals <- (real.val - pred)
MSE <- mean(residuals^2)
RMSE <- sqrt(mean(residuals^2))
SMAPE <- mean(abs(residuals)/(abs(real.val) + abs(pred))/2)*100
err <- c(MSE, RMSE, SMAPE)
names(err) <- c("MSE", "RMSE", "SMAPE")
print("Error Measurement: ")
print(err) 
