library(frbs)
library(batch)
seed <- 101
parseCommandArgs()
set.seed(seed)
library(fRegression)

## Input data
data(frbsData)
data.train <- data.frame(frbsData$MackeyGlass1000.dt[1: 500, ])
data.fit <- data.frame(data.train[, 1 : 4])
data.tst <- data.frame(frbsData$MackeyGlass1000.dt[501 : 1000, 1 : 4])
real.val <- matrix(frbsData$MackeyGlass1000.dt[501 : 1000, 5], ncol = 1)
range.data<-matrix(c(0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105), nrow=2)

colnames(data.train) <- c("d1", "d2", "d3", "d4", "d5")
colnames(data.tst) <- c("d1", "d2", "d3", "d4")
#data.test <- data.frame(frbsData$GasFurnance.dt[205 : 292, ])
#colnames(data.test) <- c("d1", "d2", "d3")

## generate model using classification tree with default parameters (for simplicity).
object.lm <- regFit(d5 ~., data.train, use = "lm")
object.glm <- regFit(d5 ~., data.train, use = "glm")
object.gam <- regFit(d5 ~., data.train, use = "gam")
object.ppr <- regFit(d5 ~., data.train, use = "ppr")

pred.lm <- predict(object.lm, data.tst)
pred.glm <- predict(object.glm, data.tst)
pred.gam <- predict(object.gam, data.tst)
pred.ppr <- predict(object.ppr, data.tst)


benchmark.lm <- cbind(real.val, pred.lm)
benchmark.glm <- cbind(real.val, pred.glm)
benchmark.gam <- cbind(real.val, pred.gam)
benchmark.ppr <- cbind(real.val, pred.ppr)

residuals.lm <- (real.val - pred.lm)
residuals.glm <- (real.val - pred.glm)
residuals.gam <- (real.val - pred.gam)
residuals.ppr <- (real.val - pred.ppr)

MSE.lm <- mean(residuals.lm^2)
MSE.glm <- mean(residuals.glm^2)
MSE.gam <- mean(residuals.gam^2)
MSE.ppr <- mean(residuals.ppr^2)

RMSE.lm <- sqrt(mean(residuals.lm^2))
RMSE.glm <- sqrt(mean(residuals.glm^2))
RMSE.gam <- sqrt(mean(residuals.gam^2))
RMSE.ppr <- sqrt(mean(residuals.ppr^2))


SMAPE.lm <- mean(abs(residuals.lm)/(abs(real.val) + abs(pred.lm))/2)*100
SMAPE.glm <- mean(abs(residuals.glm)/(abs(real.val) + abs(pred.glm))/2)*100
SMAPE.gam <- mean(abs(residuals.gam)/(abs(real.val) + abs(pred.gam))/2)*100
SMAPE.ppr <- mean(abs(residuals.ppr)/(abs(real.val) + abs(pred.ppr))/2)*100

err.lm <- c(MSE.lm, RMSE.lm, SMAPE.lm)
err.glm <- c(MSE.glm, RMSE.glm, SMAPE.glm)
err.gam <- c(MSE.gam, RMSE.gam, SMAPE.gam)
err.ppr <- c(MSE.ppr, RMSE.ppr, SMAPE.ppr)

names(err.lm) <- c("MSE", "RMSE", "SMAPE")
names(err.glm) <- c("MSE", "RMSE", "SMAPE")
names(err.gam) <- c("MSE", "RMSE", "SMAPE")
names(err.ppr) <- c("MSE", "RMSE", "SMAPE")

print("Error Measurement: ")
print(err.lm) 
print(err.glm) 
print(err.gam) 
print(err.ppr) 
