library(frbs)
library(batch)
seed <- 101
parseCommandArgs()
set.seed(seed)
library(frbs)
library(CORElearn)

## Input data
data(frbsData)
frbsData$MackeyGlass1000.dt <- frbsData$MackeyGlass1000.dt[sample(nrow(frbsData$MackeyGlass1000.dt)), ]
data.train <- data.frame(frbsData$MackeyGlass1000.dt[1: 500, ])
data.fit <- data.frame(data.train[, 1 : 4])
data.tst <- data.frame(frbsData$MackeyGlass1000.dt[501 : 1000, 1 : 4])
real.val <- matrix(frbsData$MackeyGlass1000.dt[501 : 1000, 5], ncol = 1)
range.data<-matrix(c(0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105, 0.43462, 1.3105), nrow=2)
colnames(data.train) <- c("d1", "d2", "d3", "d4", "d5")
colnames(data.tst) <- c("d1", "d2", "d3", "d4")
data.test <- data.frame(frbsData$MackeyGlass1000.dt[501 : 1000, ])
colnames(data.test) <- c("d1", "d2", "d3", "d4", "d5")

## generate model using classification tree with default parameters (for simplicity).
object.LWR <- CoreModel(d5 ~., data.train, model = "regTree", modelTypeReg = 1)

pred <- predict(object.LWR, data.test, type="probability")

benchmark <- cbind(real.val, pred)

colnames(benchmark) <- c("real", "tree")
print(benchmark)
residuals <- (real.val - pred)
MSE <- mean(residuals^2)
RMSE <- sqrt(mean(residuals^2))
SMAPE <- mean(abs(residuals)/(abs(real.val) + abs(pred))/2)*100
err <- c(MSE, RMSE, SMAPE)
names(err) <- c("MSE", "RMSE", "SMAPE")
print("Error Measurement: ")
print(err) 
